==> haskell-checkers-0.4.14-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.14
id: checkers-0.4.14-DJlg3NVTtWoF5YF1pYHvTg
key: checkers-0.4.14-DJlg3NVTtWoF5YF1pYHvTg
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: 57c9a4ca65739f18df42adbbefcba9b8
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.4.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/checkers-0.4.14
hs-libraries: HScheckers-0.4.14-DJlg3NVTtWoF5YF1pYHvTg
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 array-0.5.3.0
    base-4.12.0.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    semigroupoids-5.3.2-FtBLM63lUATpU66Ygzl45
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.4.14-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.14
id: checkers-0.4.14-2eZ6Vhg35Y45wBHf3CjFrH
key: checkers-0.4.14-2eZ6Vhg35Y45wBHf3CjFrH
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: 516bc76c95f6d5467336fe7a7d4c4cd3
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.4.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/checkers-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/checkers-0.4.14
hs-libraries: HScheckers-0.4.14-2eZ6Vhg35Y45wBHf3CjFrH
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 array-0.5.3.0
    base-4.12.0.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    semigroupoids-5.3.2-D0FzR50kHmfGimsatrgpKn
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
